@@ -174,4 +174,4 @@ class Actor:
         y = sum([point.y for point in points]) / len(points)
         z = sum([point.z for point in points]) / len(points)
 
-        return (x, y, z)
+        return Point3D(x, y, z)
