@@ -1,12 +1,13 @@
 """A VTK representation of HBModel."""
 
 from __future__ import annotations
+from json.decoder import JSONDecodeError
 import pathlib
 import shutil
 import webbrowser
 import tempfile
 import os
-import warnings
+
 from collections import defaultdict
 from typing import Dict, List
 from honeybee.facetype import face_types
@@ -18,6 +19,7 @@ from .to_vtk import convert_aperture, convert_face, convert_room, convert_shade,
     convert_sensor_grid
 from .vtkjs.schema import IndexJSON, DisplayMode, SensorGridOptions
 from .vtkjs.helper import convert_directory_to_zip_file, add_data_to_viewer
+from .types import model_dataset_names
 
 
 _COLORSET = {
@@ -56,9 +58,10 @@ class Model(object):
     You can control the style for each type separately.
 
     """
+
     def __init__(
-        self, model: HBModel,
-        load_grids: SensorGridOptions = SensorGridOptions.Ignore) -> None:
+            self, model: HBModel,
+            load_grids: SensorGridOptions = SensorGridOptions.Ignore) -> None:
         """Instantiate a honeybee-vtk model object.
 
         Args:
@@ -153,6 +156,23 @@ class Model(object):
         """List of Camera objects attached to this Model object."""
         return self._cameras
 
+    def get_modeldataset_from_string(self, text: str) -> ModelDataSet:
+        """Get a ModelDataSet object from a model using a text string.
+
+        Args:
+            text: A text string such as "walls", "shades"
+
+        Returns:
+            A ModelDataSet object.
+        """
+        if text not in model_dataset_names:
+            raise ValueError(
+                f'Text must be one of the {model_dataset_names}.'
+                f' Instead got {text}.'
+            )
+        ds = {ds.name.lower(): ds for ds in self}
+        return ds[text]
+
     def __iter__(self):
         """This dunder method makes this class an iterator object.
 
@@ -164,7 +184,7 @@ class Model(object):
         for dataset in (
             self.apertures, self.walls, self.shades, self.doors, self.floors,
             self.roof_ceilings, self.air_boundaries, self.sensor_grids
-                ):
+        ):
             yield dataset
 
     def _load_grids(self, model: HBModel, grid_options: SensorGridOptions) -> None:
@@ -182,10 +202,6 @@ class Model(object):
         if len(model.properties.radiance.views) > 0:
             for view in model.properties.radiance.views:
                 self._cameras.append(Camera.from_view(view))
-        else:
-            warnings.warn(
-                'views not found in HBJSON.'
-            )
 
     def update_display_mode(self, value: DisplayMode) -> None:
         """Change display mode for all the object types in the model.
@@ -204,23 +220,23 @@ class Model(object):
     def _convert_model(self, model: HBModel) -> None:
         """An internal method to convert the objects on class initiation."""
 
-        for room in model.rooms:
-            objects = convert_room(room)
-            self._add_objects(self.separate_by_type(objects))
+        if hasattr(model, 'rooms'):
+            for room in model.rooms:
+                objects = convert_room(room)
+                self._add_objects(self.separate_by_type(objects))
 
-        for face in model.faces:
-            objects = convert_face(face)
-            self._add_objects(self.separate_by_type(objects))
+        if hasattr(model, 'orphaned_shades'):
+            for face in model.orphaned_shades:
+                self._shades.data.append(convert_shade(face))
 
-        for face in model.orphaned_shades:
-            self._shades.data.append(convert_shade(face))
+        if hasattr(model, 'orphaned_apertures'):
+            for face in model.orphaned_apertures:
+                self._apertures.data.extend(convert_aperture(face))
 
-        for face in model.orphaned_apertures:
-            self._apertures.data.extend(convert_aperture(face))
-
-        for face in model.orphaned_faces:
-            objects = convert_face(face)
-            self._add_objects(self.separate_by_type(objects))
+        if hasattr(model, 'orphaned_faces'):
+            for face in model.orphaned_faces:
+                objects = convert_face(face)
+                self._add_objects(self.separate_by_type(objects))
 
     def _add_objects(self, data: Dict) -> None:
         """Add object to different fields based on data type.
@@ -339,7 +355,7 @@ class Model(object):
             webbrowser.open(html_file)
         return html_file
 
-    @staticmethod
+    @ staticmethod
     def get_default_color(face_type: face_types) -> Color:
         """Get the default color based of face type.
 
@@ -350,7 +366,7 @@ class Model(object):
         color = _COLORSET.get(face_type, [1, 1, 1, 1])
         return Color(*(v * 255 for v in color))
 
-    @staticmethod
+    @ staticmethod
     def separate_by_type(data: List[PolyData]) -> Dict:
         """Separate PolyData objects by type."""
         data_dict = defaultdict(list)
