@@ -19,6 +19,10 @@ from .legend_parameter import LegendParameter, Colors
 from .vtkjs.schema import DataSetProperty, DataSet, DisplayMode, DataSetMapper
 
 
+model_dataset_names = ('wall', 'aperture', 'shade', 'door', 'floor', 'roofceiling',
+                       'airboundary', 'grid')
+
+
 class VTKWriters(Enum):
     """Vtk writers."""
     legacy = 'vtk'
@@ -46,7 +50,7 @@ class DataFieldInfo:
     Args:
         name: A string representing the name of for data.
         range: A tuple of min, max values. Defaults to (0, 100).
-        colors: A Colors object that defines colors for the legend. 
+        colors: A Colors object that defines colors for the legend.
             Defaults to Ecotect colorset.
         per_face : A Boolean to indicate if the data is per face or per point. In
             most cases except for sensor points that are loaded as sensors the data
@@ -303,9 +307,10 @@ class ModelDataSet:
             data_range: A list with two values for minimum and maximum values for legend
                 parameters.
         """
+
         assert len(self.data) == len(data), \
-            f'Length of input data {len(data)} does not match the length of polydata ' \
-            f'in this dataset {len(self.data)}.'
+            f'Length of input data {len(data)} does not match the length of'\
+            f' polydata in this dataset {len(self.data)}.'
 
         for count, d in enumerate(data):
             self.data[count].add_data(
